----------------------------------
-- Create plugin

local RW = LibStub("AceAddon-3.0"):GetAddon("Raid Watch")
local plugin = RW:Plugin("RaidSpecs")
if not plugin then return end

----------------------------------
-- Locals 
local LGT = LibStub("LibGroupInSpecT-1.1")
local L = LibStub("AceLocale-3.0"):GetLocale("RW2-Plugin-RaidSpecs")
local LB = LibStub("AceLocale-3.0"):GetLocale("RW2-Plugin-Base")
local LBB = LibStub("AceLocale-3.0"):GetLocale("RW2-Base")
local LSM = LibStub("LibSharedMedia-3.0")
local AGU = LibStub("AceGUI-3.0")
local UIF

local db
local Utils = RW.Utils
local PluginIcon = [[Interface\Icons\Achievement_Reputation_08]]

local Window, ConfigWindow, Anchor
local dragStart, dragStop
local Party

local defaults = {
	profile = {
		PluginEnabled = true,
		x = 0, 
		y = 0,
		Width = 300,	

		NotifyRoleChange = false,
		NotifySpecChange = false,
	}
}

----------------------------------
-- Init
function plugin:OnRegister()
	self.db = RW.db:RegisterNamespace(self:GetName(), defaults)
	db = self.db.profile
	
	self.db.RegisterCallback(self, "OnProfileChanged", "Reset")
	self.db.RegisterCallback(self, "OnProfileCopied", "Reset")
	self.db.RegisterCallback(self, "OnProfileReset", "Reset")
	
	LGT.RegisterCallback(self, "GroupInSpecT_Update", "SpecUpdate")
	--LGT.RegisterCallback(self, "LibGroupTalents_Update", "SpecUpdate")
end

function plugin:PluginEnable()
	if not db.PluginEnabled then
		self:Disable()
		return
	end
	db.SpecTable = {}
	UIF = LibStub("LibGUIFactory-1.0"):GetFactory("RW")
	
	Party = RW.Party
	
	LGT.RegisterCallback(self, "GroupInSpecT_Update", "SpecUpdate")
	--LGT.RegisterCallback(self, "LibGroupTalents_Update", "SpecUpdate")
	
	self:Reset()
end

function plugin:PluginDisable()
	LGT.UnregisterCallback(self, "GroupInSpecT_Update")
	--LGT.UnregisterCallback(self, "LibGroupTalents_Update")
end

function plugin:Reset()
	db = self.db.profile
end

-- Events ------------------------------------
----------------------------------------------
--[[function plugin:RoleChanged(event, guid, unit, newRole, oldRole)
	db.SpecTable[guid] = db.SpecTable[guid] or {}
	db.SpecTable[guid].role = newRole
	if db.NotifyRoleChange and oldRole then
		RW.Callbacks:Fire("MessageShow", UnitName(unit).." changed from "..LBB[string.upper(oldRole)].." to "..LBB[string.upper(newRole)], nil, nil, nil, nil, db.SpecTable[guid].icon)
	end
end
]]

function plugin:SpecUpdate(event, guid, unit, info)	
	db.SpecTable[guid] = db.SpecTable[guid] or {}
	
	local oldSpec = db.SpecTable[guid].spec
	local oldRole = db.SpecTable[guid].role	
	
	if oldSpec and info.spec_index ~= oldSpec and db.NotifySpecChange then
		self:Msg(UnitName(unit).." speced "..info.spec_name_localized.." from "..db.SpecTable[guid].speccName)
	end	
	
	if db.NotifyRoleChange and oldRole and info.spec_role ~= oldRole then
		RW.Callbacks:Fire("MessageShow", UnitName(unit).." changed from "..LBB[string.upper(oldRole)].." to "..LBB[string.upper(info.spec_role)], nil, nil, nil, nil, db.SpecTable[guid].icon)
	end
	
	db.SpecTable[guid].spec = info.spec_index
	db.SpecTable[guid].tree = treeNumber
	db.SpecTable[guid].icon = info.spec_icon
	db.SpecTable[guid].role = info.spec_role
	db.SpecTable[guid].speccName = info.spec_name_localized
end


-- UI ----------------------------------------
----------------------------------------------
do
	function plugin:GetOptions()
		return {{text = LB.PLUGINS, value = "Plugins"}, {text = L.NAME, value = "RaidSpecs", order = 90}}, self.GetGUI, PluginIcon
	end
	
	
	function plugin:GetGUI()
		self = plugin
		
		local scroll = AGU:Create("SimpleGroup")	
		scroll:SetFullWidth(true)
		scroll:SetLayout("Flow")
		
		local label = UIF:MainTitleLabel(L.NAME)
		scroll:AddChild(label)	
		
		-- Information
		local infogroup = UIF:InlineGroup1()
		label = UIF:Text1(L.DESC)
		label:SetImage(PluginIcon)
		infogroup:AddChild(label)
		scroll:AddChild(infogroup)
		
		local group = UIF:InlineGroup()
		scroll:AddChild(group)
		
		group:AddChild(UIF:CheckBox("Notify role change", db, "NotifyRoleChange", nil, "Will notify when someone in the raid/party changes spec to a different role, eg. Tank -> DPS", 0.5))
		group:AddChild(UIF:CheckBox("Notify spec change", db, "NotifySpecChange", nil, "Will notify whenever someone changes spec, eg. Unholy -> Frost", 0.5))
		
		return scroll
	end
end